@echo off
rem *****************************************************************
rem *	File:	Template.Cmd
rem *	Date:	September 2000
rem *****************************************************************
rem * Description: Generic application script template.
rem * You should use this script in conjunction with the 'Application 
rem * support' chapter of the user manual.
rem *
rem * This script provides a template that can be used to stop and
rem * start application processes and/or services on both the primary
rem * and secondary server, as a part of the failover and reinstate
rem * process.
rem *
rem * To use this template as part of your replication task, modify
rem * the PROC_LIST, SERVICE_LIST and APP_LIST variables below by
rem * detailing the services and processes in startup order.  Next,
rem * review the eight actions to verify that they perform the correct
rem * functions for your specific application. Save your customized
rem * script with a unique name.
rem *
rem * To use this script as part of a replication task, include it
rem * in each of the eight Failover Actions in the replication task.
rem *
rem * When SurviveIT invokes a script, it sets three
rem * environment variables that allows this script to determine
rem * the most appropriate action to take.
rem * 1) OPERATION: It will be set to one of the following values:
rem *  		PRE_FAILOVER_PRIMARY	PRE_FAILOVER_SECONDARY
rem *		POST_FAILOVER_PRIMARY	POST_FAILOVER_SECONDARY
rem *		PRE_REINSTATE_PRIMARY	PRE_REINSTATE_SECONDARY
rem *		POST_REINSTATE_PRIMARY	POST_REINSTATE_SECONDARY
rem * 2) ASR_OP_STATUS: Notifies if Failover or Reinstatement failed.
rem *	= FALSE for Post-Operation scripts where Operation failed.
rem *	= TRUE otherwise.
rem * 3) ASR_PRE_RUN: Notifies if Pre-Operation script has been run.
rem *	= FALSE in Post-Operation scripts where Pre-Operation script
rem *		was not run (e.g. Powerfail scenario).
rem *	= TRUE otherwise.
rem *****************************************************************
setlocal
rem * 
rem * You need to edit this script to define the following variables
rem *	SERVICE_LIST	Defines a list of services to action. Each
rem *			service can be specified using its display
rem *			name or its registry key name. Multiple
rem *			service names should be separated with a
rem *			space.
rem *			Service names that include spaces MUST be
rem *			enclosed in quotes, e.g.
rem *			SET SERVICE_LIST="Client Agent for ARCserveIT"
rem *				
rem *	APP_LIST	Defines a list of application processes to start.
rem *			Application names should be separated with spaces.
rem *			They should also always be enclosed in quotes.
rem *			Arguments may be passed by also enclosing in the quotes.
rem *
rem *	PROC_LIST	Defines a list of processes to be stopped by asrkill.
rem *			These can be determined by using 'asrkill -v'. The
rem *			names should not be enclosed in quotes.
rem *
rem *****************************************************************

rem *****************************************************************
rem * YOU MUST MODIFY THE VALUE OF THESE VARIABLES
rem * See the notes above for how they should be customized.
rem * If you have no processes or services to control then set the 
rem * relevant list to null, do not delete the assignment, eg.
rem *      set SERVICE_LIST=service1 service2
rem *      set APP_LIST=
rem *      set PROC_LIST=
rem *****************************************************************

set SERVICE_LIST=service1 service2
set APP_LIST="app1" "app2"
set PROC_LIST=proc1 proc2

rem *****************************************************************
rem * Set the name of the logfile by resetting the value of LOG_NAME
rem *****************************************************************
set LOG_NAME=Template

rem *****************************************************************
rem * To disable logging pass 'OFF' as the first parameter to SetLogging
rem * Pass in the name of the logfile as the second parameter
rem *****************************************************************
call :SetLogging ON "%LOG_NAME%.log"

rem *****************************************************************
rem * The following eight actions have been pre-configured to 
rem * perform the typical operations required for application
rem * failover. Should your application require actions other than
rem * those defined below, amend them to meet your application's 
rem * requirements.
rem *****************************************************************


rem *****************************************************************
rem * Call Function to carry out action depending on OPERATION
rem *****************************************************************
call :Handle_%OPERATION%
if not %errorlevel%==1 goto end
echo Error: OPERATION set to bad value: %OPERATION% >>%LOG_FILE%
set elevel=1
goto end

rem *****************************************************************
rem * OPERATION dependent functions
rem *****************************************************************
:Handle_PRE_FAILOVER_PRIMARY
call :StopApp
goto :eof

:Handle_PRE_FAILOVER_SECONDARY
REM No operation required
goto :eof

:Handle_POST_FAILOVER_PRIMARY
if "%ASR_OP_STATUS%" == "FALSE" goto HandleFailoverAbort
if not "%ASR_PRE_RUN%" == "FALSE" goto :eof
REM Powerfail prevented running PreFail script, so stop application now.
call :StopApp
goto :eof
:HandleFailoverAbort
REM Failover has failed, so we need to restart application.
call :StartApp
goto :eof

:Handle_POST_FAILOVER_SECONDARY
if "%ASR_OP_STATUS%" == "FALSE" goto :eof
call :StartApp
goto :eof

:Handle_PRE_REINSTATE_PRIMARY
REM No operation required
goto :eof

:Handle_PRE_REINSTATE_SECONDARY
call :StopApp
goto :eof

:Handle_POST_REINSTATE_PRIMARY
if "%ASR_OP_STATUS%" == "FALSE" goto :eof
call :StartApp
goto :eof

:Handle_POST_REINSTATE_SECONDARY
if not "%ASR_OP_STATUS%" == "FALSE" goto :eof
REM Reinstatement has failed, so we need to restart application.
call :StartApp
goto :eof

rem *****************************************************************
rem * Below here are defined various helper functions
rem *****************************************************************
:ASRSCtlReverse
set ACTION_LIST=
set REVERSE_LIST=
:NextAction
if /i '%1' == '/STOP' set ACTION_LIST=%ACTION_LIST% %1 && shift && goto NextAction
if /i '%1' == '/START' set ACTION_LIST=%ACTION_LIST% %1 && shift && goto NextAction
if /i '%1' == '/AUTO' set ACTION_LIST=%ACTION_LIST% %1 && shift && goto NextAction
if /i '%1' == '/MANUAL' set ACTION_LIST=%ACTION_LIST% %1 && shift && goto NextAction
if /i '%1' == '/DISABLE' set ACTION_LIST=%ACTION_LIST% %1 && shift && goto NextAction
if /i '%1' == '/LOG' set ACTION_LIST=%ACTION_LIST% %1 && shift && goto NextAction
:ReverseList
set REVERSE_LIST=%1 %REVERSE_LIST%
shift
if not '%1' == '' goto ReverseList
call :Execute ASRSCtl %ACTION_LIST% %REVERSE_LIST%
goto :eof

:Execute
echo ----------------------------------------- >>%LOG_FILE%
%* >>%LOG_FILE%
set newelevel=%errorlevel%
echo ----------------------------------------- >>%LOG_FILE%
echo "%*" exited with %newelevel% >>%LOG_FILE%
if %elevel%==0 set elevel=%newelevel%
goto :eof

:SetLogging
set elevel=0
set ASR_LOG=
set LOG_FILE=NUL
if /i "%1"=="OFF" goto :eof
set ASR_LOG=/log
set LOG_FILE=%2
echo ************************************ >>%LOG_FILE%
echo Performing %OPERATION% for task %PRIMARY_NAME% to %SECONDARY_NAME% >>%LOG_FILE%
date /t >>%LOG_FILE%
time /t >>%LOG_FILE%
goto :eof
:StartApp
for %%a in (%app_list%) do start /i /min "%%a"
if "%ASR_LOG%" == "/log" echo Apps started >>%LOG_FILE%
if not "%SERVICE_LIST%" == "" call :Execute ASRSCtl /auto /start %ASR_LOG% %SERVICE_LIST%
goto :eof

:StopApp
for %%p in (%proc_list%) do start /i /min ASRKill %%p
if "%ASR_LOG%" == "/log" echo Apps killed >>%LOG_FILE%
if not "%SERVICE_LIST%" == "" call :ASRSCtlReverse /manual /stop %ASR_LOG% %SERVICE_LIST%
goto :eof

:end
Echo Script completing with exit code %elevel% >>%LOG_FILE%
ASRError %elevel%
